==> zither-1.1.15.tar.gz: zither_prj/almemsys/test.c <==
// test.c
// $Id: test.c,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
// masashi shimakura

#include<stdio.h>
#include<stdlib.h>
#include<string.h>
/* #include<almemsys.h>  */
#include"almemsys.h"

int main(void)
{
int ret, sta, sto;
char * taro = (char *)calloc(12, sizeof(char));
char * hana = (char *)calloc(12, sizeof(char));
char * sachi = (char *)calloc(12, sizeof(char));

ret = 0;
sta = 0;
sto = 0;

alversion();

taro = safe_memcpy(taro, "abcdef", 256);
printf("SAFE_MEMCPY DATA =%s\n", taro);
taro = safe_strncat(taro, "12345", 256);
printf("SAFE_STRNCAT DATA =%s\n", taro);
hana = safe_sprintf(hana, 256,"%s, %s, %s\n", taro, "fvbj", "12345");
printf("SAFE_SPRINTF DATA =%s\n", hana);
sachi = delim_get(hana, sachi, ',', &ret, 0);
printf("DELIM_GET DATA1 =%s\n", sachi);
sachi = delim_get(hana, sachi, ',', &ret, 1);
printf("DELIM_GET DATA2 =%s\n", sachi);
sachi = delim_get(hana, sachi, ',', &ret, 2);
printf("DELIM_GET DATA3 =%s\n", sachi);
sachi = delim_get(hana, sachi, ',', &ret, 3);
printf("DELIM_GET DATA4 =%s\n", sachi);
taro = safe_memcpy(taro, "-a-1-20-345", 256);
printf("SAFE_MEMCPY DATA =%s", taro);
ret = ch_int(taro);
printf("CH_INT DATA= %s RET=%d\n", taro, ret);
ret = char_count(taro, '-');
printf("CHAR_COUNT DATA= %s RET=%d\n", taro, ret);
ret = char_get(taro, sachi, '-', 3);
printf("CHAR_GET DATA= %s DATA2= %s RET=%d\n", taro, sachi, ret);
ret = char_point(taro, '-', 4);
printf("CHAR_POINT DATA= %s RET=%d\n", taro, ret);
ret = clean_mem(taro, '+', 3);
printf("CLEAN_MEM DATA= %s RET=%d\n", taro, ret);
ret = count_memcpy(taro, "abcdefghijklmn", 3);
printf("COUNT_MEMCPY DATA= %s RET=%d\n", taro, ret);
taro = safe_memcpy(taro, "hanako-sashiko-ayako", 256);
ret = delim_count(taro, '-', 1, &sta, &sto);
printf("DELIM_COUNT DATA= %s RET=%d STA= %d STO= %d\n", taro, ret, sta, sto);
ret = mem_count(taro, '-');
printf("MEM_COUNT DATA= %s RET=%d\n", taro, ret);
ret = memcount_cpm(taro, "12345", 1, 3);
printf("MEMCOUNT_CPM DATA= %s RET=%d\n", taro, ret);
taro = safe_memcpy(taro, "abcdef\r\n", 256);
ret = rm_crlf(taro, (int)strlen(taro));
printf("RM_CRLF DATA= %s RET=%d\n", taro, ret);
ret = set_mem(taro, 'd', (int)strlen(taro));
printf("SET_MEM DATA= %s RET=%d\n", taro, ret);
taro = safe_memcpy(taro, "02020", 256);
ret = swap_mem(taro, '2', '1', strlen(taro));
printf("SWAP_MEM DATA= %s RET=%d\n", taro, ret);
ret = unlinkdir("/home/masashi/dirtest/");
printf("UNLINKDIR PATH= %s RET=%d\n", "/home/masashi/dirtest/", ret);
printf("char_wday(1) = %s\n", char_wday(1));
printf("char_mon(1) = %s\n", char_wday(1));
printf("utime_getr(0, 'y') = %d\n", utime_getr(0, 'y'));
printf("utime_getr(0, 'm') = %d\n", utime_getr(0, 'm'));
printf("utime_getr(0, 'd') = %d\n", utime_getr(0, 'd'));
printf("cutime_getr('y') = %d\n", ctime_getr('y'));
printf("cutime_getr('m') = %d\n", ctime_getr('m'));
taro = safe_memcpy(taro, "abcdefghijklmnopqrstuvwxyz<12345678910>日本語、中国語、韓国語、アラビヤ語、ミャンマー語、サンスクリット語、パーリ語、ヘブライ語、タイ語、タガログ語", 4980);
taro = safe_base64(taro, 1);
printf("=============\n");
printf("%s\n", taro);
taro = safe_memcpy(taro, "abcdefghijklmnopqrstuvwxyz<12345678910>日本語、中国語、韓国語、アラビヤ語、ミャンマー語、サンスクリット語、パーリ語、ヘブライ語、タイ語、タガログ語", 4980);
taro = safe_base64(taro, 0);
printf("=============\n");
printf("%s\n", taro);
taro = safe_base64inheader(taro, "Subject: ");
printf("=============\n");
printf("%s\n", taro);

taro = safe_memcpy(taro, "jjjjjjjjjjjjj", 1000);
taro = safe_ujtoj(taro);
printf("safe_ujtoj(): <%s>\n", taro);

return 0;
}

==> zither-1.1.17.tar.gz: zither_prj/almemsys/test.c <==
// test.c
// $Id: test.c,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
// masashi shimakura

#include<stdio.h>
#include<stdlib.h>
#include<string.h>
/* #include<almemsys.h>  */
#include"almemsys.h"

int main(void)
{
int ret, sta, sto;
char * taro = (char *)calloc(12, sizeof(char));
char * hana = (char *)calloc(12, sizeof(char));
char * sachi = (char *)calloc(12, sizeof(char));

ret = 0;
sta = 0;
sto = 0;

alversion();

taro = safe_memcpy(taro, "abcdef", 256);
printf("SAFE_MEMCPY DATA =%s\n", taro);
taro = safe_strncat(taro, "12345", 256);
printf("SAFE_STRNCAT DATA =%s\n", taro);
hana = safe_sprintf(hana, 256,"%s, %s, %s\n", taro, "fvbj", "12345");
printf("SAFE_SPRINTF DATA =%s\n", hana);
sachi = delim_get(hana, sachi, ',', &ret, 0);
printf("DELIM_GET DATA1 =%s\n", sachi);
sachi = delim_get(hana, sachi, ',', &ret, 1);
printf("DELIM_GET DATA2 =%s\n", sachi);
sachi = delim_get(hana, sachi, ',', &ret, 2);
printf("DELIM_GET DATA3 =%s\n", sachi);
sachi = delim_get(hana, sachi, ',', &ret, 3);
printf("DELIM_GET DATA4 =%s\n", sachi);
taro = safe_memcpy(taro, "-a-1-20-345", 256);
printf("SAFE_MEMCPY DATA =%s", taro);
ret = ch_int(taro);
printf("CH_INT DATA= %s RET=%d\n", taro, ret);
ret = char_count(taro, '-');
printf("CHAR_COUNT DATA= %s RET=%d\n", taro, ret);
ret = char_get(taro, sachi, '-', 3);
printf("CHAR_GET DATA= %s DATA2= %s RET=%d\n", taro, sachi, ret);
ret = char_point(taro, '-', 4);
printf("CHAR_POINT DATA= %s RET=%d\n", taro, ret);
ret = clean_mem(taro, '+', 3);
printf("CLEAN_MEM DATA= %s RET=%d\n", taro, ret);
ret = count_memcpy(taro, "abcdefghijklmn", 3);
printf("COUNT_MEMCPY DATA= %s RET=%d\n", taro, ret);
taro = safe_memcpy(taro, "hanako-sashiko-ayako", 256);
ret = delim_count(taro, '-', 1, &sta, &sto);
printf("DELIM_COUNT DATA= %s RET=%d STA= %d STO= %d\n", taro, ret, sta, sto);
ret = mem_count(taro, '-');
printf("MEM_COUNT DATA= %s RET=%d\n", taro, ret);
ret = memcount_cpm(taro, "12345", 1, 3);
printf("MEMCOUNT_CPM DATA= %s RET=%d\n", taro, ret);
taro = safe_memcpy(taro, "abcdef\r\n", 256);
ret = rm_crlf(taro, (int)strlen(taro));
printf("RM_CRLF DATA= %s RET=%d\n", taro, ret);
ret = set_mem(taro, 'd', (int)strlen(taro));
printf("SET_MEM DATA= %s RET=%d\n", taro, ret);
taro = safe_memcpy(taro, "02020", 256);
ret = swap_mem(taro, '2', '1', strlen(taro));
printf("SWAP_MEM DATA= %s RET=%d\n", taro, ret);
ret = unlinkdir("/home/masashi/dirtest/");
printf("UNLINKDIR PATH= %s RET=%d\n", "/home/masashi/dirtest/", ret);
printf("char_wday(1) = %s\n", char_wday(1));
printf("char_mon(1) = %s\n", char_wday(1));
printf("utime_getr(0, 'y') = %d\n", utime_getr(0, 'y'));
printf("utime_getr(0, 'm') = %d\n", utime_getr(0, 'm'));
printf("utime_getr(0, 'd') = %d\n", utime_getr(0, 'd'));
printf("cutime_getr('y') = %d\n", ctime_getr('y'));
printf("cutime_getr('m') = %d\n", ctime_getr('m'));

taro = safe_memcpy(taro, "jjjjjjjjjjjjj", 1000);
taro = safe_ujtoj(taro);
printf("safe_ujtoj(): <%s>\n", taro);

taro = safe_memcpy(taro, "@1234567890@", 1000);
taro = safe_ujtoj(taro);
taro = safe_memcpy(taro, "դդ줳줳ϤϤϤϤϤʤʤʤʤ", 1000);
printf("mime_ujtoj(): <%s>\n", mime_ujtoj(taro));

return 0;
}
